@@ -17,7 +17,9 @@ int main(int argc, char** argv)
   TEST_FE(bdm1cube2dlfem);
 
   Dune::BrezziDouglasMariniCubeLocalFiniteElement<double,double,3,1> bdm1cube3dlfem(1);
-  TEST_FE2(bdm1cube3dlfem, DisableLocalInterpolation);
+  // \todo Implement the missing LocalInterpolation
+  // DisableRepresentConstants is only set because the test also uses DisableLocalInterpolation internally.
+  TEST_FE2(bdm1cube3dlfem, DisableLocalInterpolation + DisableRepresentConstants);
 
   Dune::BrezziDouglasMariniCubeLocalFiniteElement<double,double,2,2> bdm2cube2dlfem(1);
   TEST_FE(bdm2cube2dlfem);
