@@ -5,13 +5,11 @@
 
 #include <iostream>
 
-#include <dune/localfunctions/hierarchical/hierarchicalp2.hh>
-#include <dune/localfunctions/hierarchical/hierarchicalp2withelementbubble.hh>
-#include <dune/localfunctions/hierarchical/hierarchicalprismp2.hh>
+#include <dune/localfunctions/hierarchical.hh>
 
 #include <dune/localfunctions/test/test-localfe.hh>
 
-int main(int argc, char** argv) try
+int main(int argc, char** argv)
 {
   bool success = true;
 
@@ -32,8 +30,3 @@ int main(int argc, char** argv) try
 
   return success ? 0 : 1;
 }
-catch (Dune::Exception e)
-{
-  std::cout << e.what() << std::endl;
-  return 1;
-}
