@@ -185,11 +185,15 @@ int main (int argc, char *argv[])
   PrismP2LocalFiniteElement<double,double> prismp2fem;
   TEST_FE3(prismp2fem, DisableNone, 1);
 
+  // Pyramid shapefunctions are not differentiable on the plane where xi[0]=xi[1].
+  // So let's skip test points on this plane
+  auto xySkip = [](const FieldVector<double,3>& xi){return std::abs(xi[0]-xi[1]) < 1e-8;};
+
   PyramidP1LocalFiniteElement<double,double> pyramidp1fem;
-  TEST_FE2(pyramidp1fem, DisableJacobian);
+  TEST_FE4(pyramidp1fem, DisableNone, 1, xySkip);
 
   PyramidP2LocalFiniteElement<double,double> pyramidp2fem;
-  TEST_FE2(pyramidp2fem, DisableJacobian);
+  TEST_FE4(pyramidp2fem, DisableNone, 1, xySkip);
 
   Hybrid::forEach(std::make_index_sequence<4>{},[&success](auto i)
   {
